# CHANGELOG

## 1.0.4

* README: improve spelling
* README: add home page and other URLs
* VERSION: remove version.py
* tox: added more versions for testing

## Other important changes

* switch to src/
* switch to pyproject.toml
* improved tests
* fixed bug in delete of subelements
* we no longer support versions prior to 1.0.4
